==> plplot_5.10.0.orig.tar.gz: plplot-5.10.0/doc/doxygen/html/tclAPI_8c.js <==
var tclAPI_8c =
[
    [ "Command", "structCommand.html", "structCommand" ],
    [ "CmdInfo", "structCmdInfo.html", "structCmdInfo" ],
    [ "PL_LIBRARY", "tclAPI_8c.html#a2173a4ba9260869ae2c7473986d38d64", null ],
    [ "PLPLOT_EXTENDED_SEARCH", "tclAPI_8c.html#afc8996c89333709dccb6e53ddf203c69", null ],
    [ "Command", "tclAPI_8c.html#a1e070cd9ac686a0bb549183eaf77290e", null ],
    [ "Append_Cmdlist", "tclAPI_8c.html#ac48c3efba7bcd2380c847607918537db", null ],
    [ "argv_to_chars", "tclAPI_8c.html#a465b6793aabf98ab5a98a2c6ee731cc3", null ],
    [ "argv_to_doubles", "tclAPI_8c.html#a745a6beb32ab13d604771663d1d2179a", null ],
    [ "argv_to_ints", "tclAPI_8c.html#a623e8233b572bc4f359b041a18ea93ae", null ],
    [ "labelform", "tclAPI_8c.html#aa94e0f0c3f6c1dd0458280e48791bc27", null ],
    [ "labelform", "tclAPI_8c.html#a0f2bba504f4c307b7f6f4dbe132098b8", null ],
    [ "loopbackCmd", "tclAPI_8c.html#a0a549425032c27fb11723dffdf716276", null ],
    [ "loopbackCmd", "tclAPI_8c.html#a02b9f1947656e4ef3bde25c4630ebf89", null ],
    [ "mapform", "tclAPI_8c.html#a76fa5082c51c2ab5ddbed707104cea4b", null ],
    [ "PlbasicInit", "tclAPI_8c.html#ad4807994b30e3048902ccaca11c0b841", null ],
    [ "plcolorbarCmd", "tclAPI_8c.html#aeba1936123cf0e3160b2ffdf322a534d", null ],
    [ "plcolorbarCmd", "tclAPI_8c.html#a5540dc8074aa5aed8604b9a6dc0b636c", null ],
    [ "plcontCmd", "tclAPI_8c.html#a20321714d02951a00aeea73c0f841420", null ],
    [ "plcontCmd", "tclAPI_8c.html#a529106af68d49d246a320fc5f2fe6ef6", null ],
    [ "plgriddataCmd", "tclAPI_8c.html#a73566e8f6b1dc4a1a3e4e0b9baf8adb3", null ],
    [ "plgriddataCmd", "tclAPI_8c.html#a36373aa284f746f1b653b573e058fef7", null ],
    [ "plimageCmd", "tclAPI_8c.html#a392a72dc7c96b627e4d160920af404c5", null ],
    [ "plimageCmd", "tclAPI_8c.html#a783f6565238cab48a5458e9f99a1cfe4", null ],
    [ "plimagefrCmd", "tclAPI_8c.html#a38b9f60a210c238981e02c33ca0b925b", null ],
    [ "plimagefrCmd", "tclAPI_8c.html#abcf27f3691cbfe0d3d9eb21f1dce3bf7", null ],
    [ "pllegendCmd", "tclAPI_8c.html#ad4ae3d75a25c0d464306881447170c10", null ],
    [ "pllegendCmd", "tclAPI_8c.html#a1a44cd8604f3cb8551b5357fe7ad121f", null ],
    [ "plmapCmd", "tclAPI_8c.html#a3017c43a96f32b736bce73596df2585f", null ],
    [ "plmapCmd", "tclAPI_8c.html#afc5db34202595af2b7f9f42c3c0f6b66", null ],
    [ "plmeridiansCmd", "tclAPI_8c.html#a8f692c5ed65dd8cd0cf06c0eed05fd69", null ],
    [ "plmeridiansCmd", "tclAPI_8c.html#a426ee00877a30fe567e6433659682758", null ],
    [ "plmeshcCmd", "tclAPI_8c.html#a266cdc75b819dd5cbd60ce545153469a", null ],
    [ "plmeshcCmd", "tclAPI_8c.html#a67b61ffb1f5314d28787c404ea95251b", null ],
    [ "plmeshCmd", "tclAPI_8c.html#a420be7ac07449ab2055de5c36000e142", null ],
    [ "plmeshCmd", "tclAPI_8c.html#acdb892b869eb93398898f715b11ff73a", null ],
    [ "plot3dcCmd", "tclAPI_8c.html#ae39b0ee25b825e7e1748eef56381ed95", null ],
    [ "plot3dcCmd", "tclAPI_8c.html#ab117480706008391b305f4efe5b82090", null ],
    [ "plot3dCmd", "tclAPI_8c.html#a7bf8ac7f65966950e1f82f8d0a0cf35a", null ],
    [ "plot3dCmd", "tclAPI_8c.html#a08c4a9d9733f7979b9d3fdd2202dfecf", null ],
    [ "plranddCmd", "tclAPI_8c.html#a2c0083babb13949cb702765bd9403f23", null ],
    [ "plranddCmd", "tclAPI_8c.html#a6a9911dba6da2923fadbae1a19e47864", null ],
    [ "pls_auto_path", "tclAPI_8c.html#abbbc66f3349c21258f0cc73a7a43057f", null ],
    [ "plsetoptCmd", "tclAPI_8c.html#ad3075f0529c3ebedf1547d7cfe25e07c", null ],
    [ "plsetoptCmd", "tclAPI_8c.html#ae4c18512ca1e8f77dcd76ff7d1089092", null ],
    [ "plshadeCmd", "tclAPI_8c.html#a7dd903e59ce562d67ff3736ef270891a", null ],
    [ "plshadeCmd", "tclAPI_8c.html#adb15621d672831b3d46e96bca0472bca", null ],
    [ "plshadesCmd", "tclAPI_8c.html#aebba60db8eb0429dea42ca4af14234c6", null ],
    [ "plshadesCmd", "tclAPI_8c.html#abf0be29fc3dc6643a3dd8a626353c2f1", null ],
    [ "plslabelfuncCmd", "tclAPI_8c.html#a9ae376907e587808c32087aaa1b20b2e", null ],
    [ "plslabelfuncCmd", "tclAPI_8c.html#ac2206407576ff4f1e4eb5a3652130e03", null ],
    [ "plstransformCmd", "tclAPI_8c.html#ac88f2043c655d0c120e6be388db228d1", null ],
    [ "plstransformCmd", "tclAPI_8c.html#afc5e68b20299a090e3bd029c0479a6d6", null ],
    [ "plstripcCmd", "tclAPI_8c.html#a97e95a1a1a21bb8b48925d80ed0bfdd1", null ],
    [ "plstripcCmd", "tclAPI_8c.html#ab114d8a0a4009c28f961552c4ceeea4c", null ],
    [ "plsurf3dCmd", "tclAPI_8c.html#a6f8d439a58fcd0cd7879171a50d625ff", null ],
    [ "plsurf3dCmd", "tclAPI_8c.html#a965f67e65a105d7ce40bd26d968fee0a", null ],
    [ "plsvectCmd", "tclAPI_8c.html#aaae888d1162577160501cec827f27697", null ],
    [ "plsvectCmd", "tclAPI_8c.html#a32dc712f5bef64720bca78c684b72649", null ],
    [ "Pltcl_Init", "tclAPI_8c.html#ab52e3b8cbd25f5d14cafc25d3250f28f", null ],
    [ "plTclCmd", "tclAPI_8c.html#ae56a0c821c5d6be2284dafd6bb3c45cc", null ],
    [ "plTclCmd_Init", "tclAPI_8c.html#a07e281dc8533e4cb22a65850f5ab74a5", null ],
    [ "plvectCmd", "tclAPI_8c.html#a068af7c79b9817c4a6cbd16148d57d79", null ],
    [ "plvectCmd", "tclAPI_8c.html#a4a30e792d24c85721e461152ead30b06", null ],
    [ "plWait_Until", "tclAPI_8c.html#afcb55da1c021ec0078856ddc7af459a0", null ],
    [ "tcl_cmd", "tclAPI_8c.html#a069c1e1f6fb17be5b26f89d96650d1a0", null ],
    [ "Tcl_transform", "tclAPI_8c.html#ac10d278b0793f65aa2d27b3ca83aed5c", null ],
    [ "tclMatrix_feval", "tclAPI_8c.html#a92aef5e047b1e762bf45ec49531a072a", null ],
    [ "buf", "tclAPI_8c.html#a095f0dd49eb8681e3a9d4632a98bb06e", null ],
    [ "Cmds", "tclAPI_8c.html#afffd7394c52d36f514b32e59ffb3e14c", null ],
    [ "cmdTable", "tclAPI_8c.html#afe46d728dc7638d78e6a6b199b02848a", null ],
    [ "cmdTable_initted", "tclAPI_8c.html#a52ac14dc5aeacc898515ad58d0182c1b", null ],
    [ "errmsg", "tclAPI_8c.html#a04f3effbd8fc6a0e7671a5e2c5f69c74", null ],
    [ "label_objs", "tclAPI_8c.html#a65f251f166bca0f7552e3e7859945593", null ],
    [ "pl_errcode", "tclAPI_8c.html#aa4330b21fe130af134956c1e90251854", null ],
    [ "plplotLibDir", "tclAPI_8c.html#aa2fe43714e7093fd2aade5175e479d54", null ],
    [ "return_code", "tclAPI_8c.html#a934c111b1421c6aa91507fabd5c96deb", null ],
    [ "tcl_interp", "tclAPI_8c.html#a3d50118fc7d204cae779a3aadf343961", null ],
    [ "tcl_xform_code", "tclAPI_8c.html#ac3eb3dd158b89704dccef04dbf62b78b", null ],
    [ "tcl_xform_interp", "tclAPI_8c.html#aec42596b57526cbc7c235153398be511", null ],
    [ "tcl_xform_procname", "tclAPI_8c.html#a70dd8db828f17a5bf66bb420d03488e9", null ],
    [ "tcl_xform_template", "tclAPI_8c.html#a2054b0cb8e7c5cb9e1e15fadb406190a", null ],
    [ "tclmateval_modx", "tclAPI_8c.html#aba504a266bbd2e97f015785d3d331ffa", null ],
    [ "tclmateval_mody", "tclAPI_8c.html#a96adc2705d2e72346841c32cd1c42a57", null ],
    [ "transform_name", "tclAPI_8c.html#a36ffd1f05a102966da61b0d54fa1fcd0", null ]
];

==> plplot-5.11.1.tar.gz: plplot-5.11.1/doc/doxygen/html/tclAPI_8c.js <==
var tclAPI_8c =
[
    [ "Command", "structCommand.html", "structCommand" ],
    [ "CmdInfo", "structCmdInfo.html", "structCmdInfo" ],
    [ "PL_LIBRARY", "tclAPI_8c.html#a2173a4ba9260869ae2c7473986d38d64", null ],
    [ "PLPLOT_EXTENDED_SEARCH", "tclAPI_8c.html#afc8996c89333709dccb6e53ddf203c69", null ],
    [ "Command", "tclAPI_8c.html#a1e070cd9ac686a0bb549183eaf77290e", null ],
    [ "argv_to_chars", "tclAPI_8c.html#a465b6793aabf98ab5a98a2c6ee731cc3", null ],
    [ "argv_to_doubles", "tclAPI_8c.html#a745a6beb32ab13d604771663d1d2179a", null ],
    [ "argv_to_ints", "tclAPI_8c.html#a623e8233b572bc4f359b041a18ea93ae", null ],
    [ "GetEntries", "tclAPI_8c.html#ac277fc1a34456aa0621c7692d08163b9", null ],
    [ "labelform", "tclAPI_8c.html#aa94e0f0c3f6c1dd0458280e48791bc27", null ],
    [ "labelform", "tclAPI_8c.html#a0f2bba504f4c307b7f6f4dbe132098b8", null ],
    [ "loopbackCmd", "tclAPI_8c.html#a0a549425032c27fb11723dffdf716276", null ],
    [ "loopbackCmd", "tclAPI_8c.html#a02b9f1947656e4ef3bde25c4630ebf89", null ],
    [ "mapform", "tclAPI_8c.html#a76fa5082c51c2ab5ddbed707104cea4b", null ],
    [ "PlbasicInit", "tclAPI_8c.html#ad4807994b30e3048902ccaca11c0b841", null ],
    [ "plcolorbarCmd", "tclAPI_8c.html#aeba1936123cf0e3160b2ffdf322a534d", null ],
    [ "plcolorbarCmd", "tclAPI_8c.html#a5540dc8074aa5aed8604b9a6dc0b636c", null ],
    [ "plcontCmd", "tclAPI_8c.html#a20321714d02951a00aeea73c0f841420", null ],
    [ "plcontCmd", "tclAPI_8c.html#a529106af68d49d246a320fc5f2fe6ef6", null ],
    [ "PLDLLIMPEXP_TCLTK_DATA", "tclAPI_8c.html#a0b37b901c0b99e8d084f2809b96bf8c2", null ],
    [ "plgriddataCmd", "tclAPI_8c.html#a73566e8f6b1dc4a1a3e4e0b9baf8adb3", null ],
    [ "plgriddataCmd", "tclAPI_8c.html#a36373aa284f746f1b653b573e058fef7", null ],
    [ "plimageCmd", "tclAPI_8c.html#a392a72dc7c96b627e4d160920af404c5", null ],
    [ "plimageCmd", "tclAPI_8c.html#a783f6565238cab48a5458e9f99a1cfe4", null ],
    [ "plimagefrCmd", "tclAPI_8c.html#a38b9f60a210c238981e02c33ca0b925b", null ],
    [ "plimagefrCmd", "tclAPI_8c.html#abcf27f3691cbfe0d3d9eb21f1dce3bf7", null ],
    [ "pllegendCmd", "tclAPI_8c.html#ad4ae3d75a25c0d464306881447170c10", null ],
    [ "pllegendCmd", "tclAPI_8c.html#a1a44cd8604f3cb8551b5357fe7ad121f", null ],
    [ "plmapCmd", "tclAPI_8c.html#a3017c43a96f32b736bce73596df2585f", null ],
    [ "plmapCmd", "tclAPI_8c.html#afc5db34202595af2b7f9f42c3c0f6b66", null ],
    [ "plmapfillCmd", "tclAPI_8c.html#a9c3f8e5d2bb1752b0a2a0609e4b3c6ca", null ],
    [ "plmapfillCmd", "tclAPI_8c.html#acc677de1ef82b8b510601d500197ffc3", null ],
    [ "plmaplineCmd", "tclAPI_8c.html#adc039e4618fc7b031bef89df645f70aa", null ],
    [ "plmaplineCmd", "tclAPI_8c.html#a33761f9ed46b7dc7e0971c06944de9eb", null ],
    [ "plmapstringCmd", "tclAPI_8c.html#a05476a7e14e1e135ee0b468843a3352f", null ],
    [ "plmapstringCmd", "tclAPI_8c.html#a7eb9bab0a5bec9901e1a933580043b66", null ],
    [ "plmaptexCmd", "tclAPI_8c.html#a50beff9491c0d5a5915b18d017a5c7bc", null ],
    [ "plmaptexCmd", "tclAPI_8c.html#a7071b9e1de92c386c66c1b7a946ddf2c", null ],
    [ "plmeridiansCmd", "tclAPI_8c.html#a8f692c5ed65dd8cd0cf06c0eed05fd69", null ],
    [ "plmeridiansCmd", "tclAPI_8c.html#a426ee00877a30fe567e6433659682758", null ],
    [ "plmeshcCmd", "tclAPI_8c.html#a266cdc75b819dd5cbd60ce545153469a", null ],
    [ "plmeshcCmd", "tclAPI_8c.html#a67b61ffb1f5314d28787c404ea95251b", null ],
    [ "plmeshCmd", "tclAPI_8c.html#a420be7ac07449ab2055de5c36000e142", null ],
    [ "plmeshCmd", "tclAPI_8c.html#acdb892b869eb93398898f715b11ff73a", null ],
    [ "plot3dcCmd", "tclAPI_8c.html#ae39b0ee25b825e7e1748eef56381ed95", null ],
    [ "plot3dcCmd", "tclAPI_8c.html#ab117480706008391b305f4efe5b82090", null ],
    [ "plot3dCmd", "tclAPI_8c.html#a7bf8ac7f65966950e1f82f8d0a0cf35a", null ],
    [ "plot3dCmd", "tclAPI_8c.html#a08c4a9d9733f7979b9d3fdd2202dfecf", null ],
    [ "plranddCmd", "tclAPI_8c.html#a2c0083babb13949cb702765bd9403f23", null ],
    [ "plranddCmd", "tclAPI_8c.html#a6a9911dba6da2923fadbae1a19e47864", null ],
    [ "pls_auto_path", "tclAPI_8c.html#abbbc66f3349c21258f0cc73a7a43057f", null ],
    [ "plsetoptCmd", "tclAPI_8c.html#ad3075f0529c3ebedf1547d7cfe25e07c", null ],
    [ "plsetoptCmd", "tclAPI_8c.html#ae4c18512ca1e8f77dcd76ff7d1089092", null ],
    [ "plshadeCmd", "tclAPI_8c.html#a7dd903e59ce562d67ff3736ef270891a", null ],
    [ "plshadeCmd", "tclAPI_8c.html#adb15621d672831b3d46e96bca0472bca", null ],
    [ "plshadesCmd", "tclAPI_8c.html#aebba60db8eb0429dea42ca4af14234c6", null ],
    [ "plshadesCmd", "tclAPI_8c.html#abf0be29fc3dc6643a3dd8a626353c2f1", null ],
    [ "plslabelfuncCmd", "tclAPI_8c.html#a9ae376907e587808c32087aaa1b20b2e", null ],
    [ "plslabelfuncCmd", "tclAPI_8c.html#ac2206407576ff4f1e4eb5a3652130e03", null ],
    [ "plstransformCmd", "tclAPI_8c.html#ac88f2043c655d0c120e6be388db228d1", null ],
    [ "plstransformCmd", "tclAPI_8c.html#afc5e68b20299a090e3bd029c0479a6d6", null ],
    [ "plstripcCmd", "tclAPI_8c.html#a97e95a1a1a21bb8b48925d80ed0bfdd1", null ],
    [ "plstripcCmd", "tclAPI_8c.html#ab114d8a0a4009c28f961552c4ceeea4c", null ],
    [ "plsurf3dCmd", "tclAPI_8c.html#a6f8d439a58fcd0cd7879171a50d625ff", null ],
    [ "plsurf3dCmd", "tclAPI_8c.html#a965f67e65a105d7ce40bd26d968fee0a", null ],
    [ "plsurf3dlCmd", "tclAPI_8c.html#a1476ed9579ef4f414bf8b0b8a6b300d0", null ],
    [ "plsurf3dlCmd", "tclAPI_8c.html#ab3abfdbc5583d8ef5a5cd026188d4b92", null ],
    [ "plsvectCmd", "tclAPI_8c.html#aaae888d1162577160501cec827f27697", null ],
    [ "plsvectCmd", "tclAPI_8c.html#a32dc712f5bef64720bca78c684b72649", null ],
    [ "Pltcl_Init", "tclAPI_8c.html#ab52e3b8cbd25f5d14cafc25d3250f28f", null ],
    [ "plTclCmd", "tclAPI_8c.html#ae56a0c821c5d6be2284dafd6bb3c45cc", null ],
    [ "plTclCmd_Init", "tclAPI_8c.html#a07e281dc8533e4cb22a65850f5ab74a5", null ],
    [ "plvectCmd", "tclAPI_8c.html#a068af7c79b9817c4a6cbd16148d57d79", null ],
    [ "plvectCmd", "tclAPI_8c.html#a4a30e792d24c85721e461152ead30b06", null ],
    [ "plWait_Until", "tclAPI_8c.html#afcb55da1c021ec0078856ddc7af459a0", null ],
    [ "tcl_cmd", "tclAPI_8c.html#a069c1e1f6fb17be5b26f89d96650d1a0", null ],
    [ "Tcl_transform", "tclAPI_8c.html#ac10d278b0793f65aa2d27b3ca83aed5c", null ],
    [ "tclMatrix_feval", "tclAPI_8c.html#a92aef5e047b1e762bf45ec49531a072a", null ],
    [ "buf", "tclAPI_8c.html#a095f0dd49eb8681e3a9d4632a98bb06e", null ],
    [ "Cmds", "tclAPI_8c.html#afffd7394c52d36f514b32e59ffb3e14c", null ],
    [ "cmdTable", "tclAPI_8c.html#afe46d728dc7638d78e6a6b199b02848a", null ],
    [ "cmdTable_initted", "tclAPI_8c.html#a52ac14dc5aeacc898515ad58d0182c1b", null ],
    [ "errmsg", "tclAPI_8c.html#a04f3effbd8fc6a0e7671a5e2c5f69c74", null ],
    [ "label_objs", "tclAPI_8c.html#a65f251f166bca0f7552e3e7859945593", null ],
    [ "pl_errcode", "tclAPI_8c.html#aa4330b21fe130af134956c1e90251854", null ],
    [ "return_code", "tclAPI_8c.html#a934c111b1421c6aa91507fabd5c96deb", null ],
    [ "tcl_interp", "tclAPI_8c.html#a3d50118fc7d204cae779a3aadf343961", null ],
    [ "tcl_xform_code", "tclAPI_8c.html#ac3eb3dd158b89704dccef04dbf62b78b", null ],
    [ "tcl_xform_interp", "tclAPI_8c.html#aec42596b57526cbc7c235153398be511", null ],
    [ "tcl_xform_procname", "tclAPI_8c.html#a70dd8db828f17a5bf66bb420d03488e9", null ],
    [ "tcl_xform_template", "tclAPI_8c.html#a2054b0cb8e7c5cb9e1e15fadb406190a", null ],
    [ "tclmateval_modx", "tclAPI_8c.html#aba504a266bbd2e97f015785d3d331ffa", null ],
    [ "tclmateval_mody", "tclAPI_8c.html#a96adc2705d2e72346841c32cd1c42a57", null ],
    [ "transform_name", "tclAPI_8c.html#a36ffd1f05a102966da61b0d54fa1fcd0", null ]
];
